EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Assets_CreateOrUpdateItem',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ NULL,
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'AssetItem_Id',
    /* Description_Text        */ 'Creates or updates the specified asset.'
GO

IF OBJECT_ID('[Assets_CreateOrUpdateItem]') IS NOT NULL DROP PROCEDURE [Assets_CreateOrUpdateItem]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Assets_CreateOrUpdateItem]
(
	@Feed_Id INT,
	@AssetItem_Name NVARCHAR(200) = NULL,
	@Parent_AssetItem_Id INT = NULL,
	@AssetItem_Size BIGINT = NULL,
	@ContentType_Text VARCHAR(200) = NULL,
	@MD5Hash_Bytes BINARY(16) = NULL,
	@SHA1Hash_Bytes BINARY(20) = NULL,
	@SHA256Hash_Bytes BINARY(32) = NULL,
	@SHA512Hash_Bytes BINARY(64) = NULL,
	@Modified_Date DATETIME = NULL,
	@Created_Date DATETIME = NULL,
	@Directory_Indicator YNINDICATOR = NULL,
	@CacheConfiguration_XML XML = NULL,
	@AssetItem_Id INT = NULL OUT
)
AS
BEGIN

	SET NOCOUNT ON

	-- look up existing item; this may happen if an item has been deleted
	IF @AssetItem_Id IS NULL
		SET @AssetItem_Id = (SELECT [AssetItem_Id]
		                       FROM [AssetItems]
							  WHERE [Feed_Id] = @Feed_Id
							    AND ([Parent_AssetItem_Id] = @Parent_AssetItem_Id OR ([Parent_AssetItem_Id] IS NULL AND @Parent_AssetItem_Id IS NULL))
							    AND [AssetItem_Name] = @AssetItem_Name)

    IF @AssetItem_Id IS NULL
    BEGIN

		INSERT INTO [AssetItems]
		(
			[Feed_Id],
			[Parent_AssetItem_Id],
			[AssetItem_Name],
			[AssetItem_Size],
			[ContentType_Text],
			[MD5Hash_Bytes],
			[SHA1Hash_Bytes],
			[SHA256Hash_Bytes],
			[SHA512Hash_Bytes],
			[Download_Count],
			[Modified_Date],
			[Created_Date],
			[Directory_Indicator],
			[CreatedBy_User_Name],
			[ModifiedBy_User_Name],
			[CacheConfiguration_XML]
		)
		VALUES
		(
			@Feed_Id,
			@Parent_AssetItem_Id,
			@AssetItem_Name,
			@AssetItem_Size,
			@ContentType_Text,
			@MD5Hash_Bytes,
			@SHA1Hash_Bytes,
			@SHA256Hash_Bytes,
			@SHA512Hash_Bytes,
			0,
			COALESCE(@Modified_Date, GETUTCDATE()),
			COALESCE(@Created_Date, GETUTCDATE()),
			@Directory_Indicator,
			dbo.Session_GetUserName(),
			dbo.Session_GetUserName(),
			@CacheConfiguration_XML
		)

		SET @AssetItem_Id = SCOPE_IDENTITY()
      
    END
    ELSE
    BEGIN
		UPDATE [AssetItems]
           SET [AssetItem_Name] = COALESCE(@AssetItem_Name, [AssetItem_Name]),
		       [Parent_AssetItem_Id] = COALESCE(@Parent_AssetItem_Id, [Parent_AssetItem_Id]),
			   [AssetItem_Size] = COALESCE(@AssetItem_Size, [AssetItem_Size]),
			   [ContentType_Text] = NULLIF(COALESCE(@ContentType_Text, [ContentType_Text]), ''),
			   [MD5Hash_Bytes] = COALESCE(@MD5Hash_Bytes, [MD5Hash_Bytes]),
			   [SHA1Hash_Bytes] = COALESCE(@SHA1Hash_Bytes, [SHA1Hash_Bytes]),
			   [SHA256Hash_Bytes] = COALESCE(@SHA256Hash_Bytes, [SHA256Hash_Bytes]),
			   [SHA512Hash_Bytes] = COALESCE(@SHA512Hash_Bytes, [SHA512Hash_Bytes]),
			   [Modified_Date] = COALESCE(@Modified_Date, [Modified_Date]),
			   [Created_Date] = COALESCE(@Created_Date, [Created_Date]),
			   [Directory_Indicator] = COALESCE(@Directory_Indicator, [Directory_Indicator]),
			   [CreatedBy_User_Name] = CASE WHEN [Deleted_Date] IS NOT NULL THEN dbo.Session_GetUserName() ELSE [CreatedBy_User_Name] END,
			   [ModifiedBy_User_Name] = CASE WHEN @Modified_Date IS NOT NULL THEN dbo.Session_GetUserName() ELSE [ModifiedBy_User_Name] END,
			   [Deleted_Date] = NULL,
			   [CacheConfiguration_XML] = CASE WHEN COALESCE(@CacheConfiguration_XML, [CacheConfiguration_XML]).exist('*') = 0 THEN NULL ELSE  COALESCE(@CacheConfiguration_XML, [CacheConfiguration_XML]) END
         WHERE [AssetItem_Id] = @AssetItem_Id

     END

	DECLARE @Current_Id INT = @Parent_AssetItem_Id

	-- ensure all parent directories are also undeleted
	WHILE @Current_Id IS NOT NULL
	BEGIN

		UPDATE [AssetItems]
		   SET [Deleted_Date] = NULL,
		       [Created_Date] = GETUTCDATE(),
			   [Modified_Date] = GETUTCDATE(),
			   [CreatedBy_User_Name] = dbo.Session_GetUserName(),
			   [ModifiedBy_User_Name] = dbo.Session_GetUserName()
		 WHERE [AssetItem_Id] = @Current_Id
		   AND [Deleted_Date] IS NOT NULL

		SET @Current_Id = (SELECT [Parent_AssetItem_Id]
		                     FROM [AssetItems]
							WHERE [AssetItem_Id] = @Current_Id)
	END

	UPDATE [Feeds]
	   SET [FeedState_Number] = COALESCE([FeedState_Number], 0) + 1
	 WHERE [Feed_Id] = @Feed_Id

END
GO

GRANT EXECUTE ON [Assets_CreateOrUpdateItem] TO [ProGetUser_Role]