EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Assets_GetItem',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'DataSet',
    /* DataTableNames_Csv      */ 'AssetItems(1),AssetItemMetadata',
    /* OutputPropertyNames_Csv */ 'CanonicalAssetPath_Text,CacheConfiguration_XML',
    /* Description_Text        */ 'Returns the specified item and its user-defined metadata, and outputs properly-cased path and cache configuration.'
GO

IF OBJECT_ID('[Assets_GetItem]') IS NOT NULL DROP PROCEDURE [Assets_GetItem]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Assets_GetItem]
(
	@AssetItem_Id INT,
	@CanonicalAssetPath_Text NVARCHAR(MAX) = NULL OUT,
	@Inherited_CacheConfiguration_XML XML = NULL OUT
)
AS
BEGIN

	SET NOCOUNT ON

	SELECT * 
	  FROM [AssetItems] 
	 WHERE [AssetItem_Id] = @AssetItem_Id

	SELECT *
	  FROM [AssetItemMetadata]
	 WHERE [AssetItem_Id] = @AssetItem_Id

	;WITH AI_Flat AS (
	  SELECT [Row] = 1, [AssetItem_Id] , [Parent_AssetItem_Id], [AssetItem_Name], [CacheConfiguration_Xml] 
	    FROM [AssetItems] WHERE [AssetItem_Id]= @AssetItem_Id
	  UNION ALL
	  SELECT [Row] = [Row] + 1, AI.[AssetItem_Id], AI.[Parent_AssetItem_Id], AI.[AssetItem_Name], AI.[CacheConfiguration_Xml] 
	    FROM [AssetItems] AI INNER JOIN AI_Flat AI2 ON AI2.[Parent_AssetItem_Id] = AI.[AssetItem_Id]
	)
	SELECT @CanonicalAssetPath_Text =  COALESCE(@CanonicalAssetPath_Text + '/', '') + [AssetItem_Name],
	       @Inherited_CacheConfiguration_XML = COALESCE([CacheConfiguration_Xml], @Inherited_CacheConfiguration_XML)
	  FROM AI_Flat 
	 ORDER BY [Row] DESC

END
GO

GRANT EXECUTE ON [Assets_GetItem] TO [ProGetUser_Role]