EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'DockerImages_DeleteImage',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Deletes an image.'
GO

IF OBJECT_ID('[DockerImages_DeleteImage]') IS NOT NULL DROP PROCEDURE [DockerImages_DeleteImage]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [DockerImages_DeleteImage]
(
	@Feed_Id INT,
	@Repository_Name VARCHAR(255),
	@Image_Digest VARCHAR(128)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	
	DELETE HCDI 
	  FROM [HelmChartDockerImages] HCDI 
	  INNER JOIN [DockerRepositoryTags_Extended] DRT
	    ON DRT.[DockerRepository_Id] = HCDI.[DockerRepository_Id] AND HCDI.[Tag_Name] = DRT.[Tag_Name]
	  WHERE DRT.[Feed_Id] = @Feed_Id 
		AND DRT.[Repository_Name] = @Repository_Name
		AND DRT.[Image_Digest] = @Image_Digest

	DELETE DI
	  FROM [DockerImages] DI
	       INNER JOIN [DockerRepositories] DR
		           ON DR.[DockerRepository_Id] = DI.[DockerRepository_Id]
	 WHERE [Feed_Id] = @Feed_Id
	   AND [Repository_Name] = @Repository_Name
	   AND [Image_Digest] = @Image_Digest

	EXEC [Events_RaiseEvent] 'PKGDEL', @Feed_Id, 'Package_Name', @Repository_Name, 'Package_Version', @Image_Digest

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [DockerImages_DeleteImage] TO [ProGetUser_Role]
GO